import cli
TESTFILE = '/Users/lhr/@/project-databank/ppbank/apiserver/2-IG-N'

# put_conformers_xyz(TESTFILE_xyz)
# del_conformers('2-CC-N')
# put_conformers(TESTFILE)
# replace_conformers(TESTFILE)

# get_conformers(TESTFILE_get)
# cli.get_conformers_by_energy(TESTFILE, 2)
cli.del_conformers("2-CC-N")
